@@ -611,7 +611,8 @@ namespace Ogre {
 		{
 			// in case we could not get material as it wasn't yet parsed/existent at that time.
 			mShadowCasterMaterial = MaterialManager::getSingleton().getByName(mShadowCasterMaterialName);
-			mShadowCasterMaterial->load();
+            if (!mShadowCasterMaterial.isNull())
+			    mShadowCasterMaterial->load();
 		}
 		if (!mShadowReceiverMaterial.isNull())
 		{
@@ -621,7 +622,8 @@ namespace Ogre {
 		{
 			// in case we could not get material as it wasn't yet parsed/existent at that time.
 			mShadowReceiverMaterial = MaterialManager::getSingleton().getByName(mShadowReceiverMaterialName);
-			mShadowReceiverMaterial->load();
+            if (!mShadowReceiverMaterial.isNull())
+			    mShadowReceiverMaterial->load();
 		}
     }
     //-----------------------------------------------------------------------------
